import sys
import unittest
import time
from flask import Flask

try:
    sys.modules.pop('paho.mqtt.client')
    sys.modules.pop('flask_mqtt')
except KeyError:
    pass
from flask_mqtt import Mqtt, MQTT_ERR_SUCCESS


def wait(seconds=0.5):
    time.sleep(seconds)


class FlaskMQTTTestCase(unittest.TestCase):
    def setUp(self):

        self.app = Flask(__name__)
        self.app.config['MQTT_USERNAME'] = 'mqtt'
        self.app.config['MQTT_PASSWORD'] = 'mqtt_server_one'
        
        self.app.config['MQTT2_USERNAME'] = 'mqtt2'
        self.app.config['MQTT2_PASSWORD'] = 'mqtt_server_two'
        self.app.config['MQTT2_BROKER_PORT'] = 1885
        
        self.app.config['MQTT3_USERNAME'] = 'mqtt3'
        self.app.config['MQTT3_PASSWORD'] = 'mqtt_server_three'
        self.app.config['MQTT3_BROKER_PORT'] = 1886

    def test_simple_connect(self):
        self.mqtt = Mqtt(self.app)
        self.mqtt._disconnect()

    def test_connect_same_config_prefix(self):
        self.mqtt = Mqtt(self.app)
        self.assertEqual(self.mqtt.username, 'mqtt')
        self.assertEqual(self.mqtt.password, 'mqtt_server_one')
        
        self.mqtt._disconnect()
    
    def test_connect_diff_config_prefix(self):
        self.mqtt = Mqtt(self.app, config_prefix="MQTT4")
        self.assertNotEqual(self.mqtt.username, 'mqtt')
        self.assertNotEqual(self.mqtt.password, 'mqtt_server_one')
        self.assertEqual(self.mqtt.username, None)
        self.assertEqual(self.mqtt.password, None)
        
        self.mqtt._disconnect()
    
    def test_connect_multiple_servers(self):
        self.mqtt = Mqtt(self.app, config_prefix="MQTT")
        self.mqtt2 = Mqtt(self.app, config_prefix="MQTT2")
        self.mqtt3 = Mqtt(self.app, config_prefix="MQTT3")
        
        self.assertEqual('mqtt', self.mqtt.username)
        self.assertEqual('mqtt2', self.mqtt2.username)
        self.assertEqual('mqtt3', self.mqtt3.username)
        self.assertEqual(1883, self.mqtt.broker_port)
        self.assertEqual(1885, self.mqtt2.broker_port)
        self.assertEqual(1886, self.mqtt3.broker_port)
        
        self.mqtt._disconnect()
        self.mqtt2._disconnect()
        self.mqtt3._disconnect()
    
    def test_subscribe_multiple_servers(self):
        self.subscribe_handled_mqtt = False
        self.unsubscribe_handled_mqtt = False
        self.subscribe_handled_mqtt2 = False
        self.unsubscribe_handled_mqtt2 = False
        self.subscribe_handled_mqtt3 = False
        self.unsubscribe_handled_mqtt3 = False
        
        self.mqtt = Mqtt(self.app, config_prefix="MQTT")
        self.mqtt2 = Mqtt(self.app, config_prefix="MQTT2")
        self.mqtt3 = Mqtt(self.app, config_prefix="MQTT3")
        
        @self.mqtt.on_subscribe()
        def handle_subscribe(client, userdata, mid_, granted_qos):
            self.subscribe_handled_mqtt = True
        
        @self.mqtt.on_unsubscribe()
        def handle_unsubscribe(client, userdata, mid_):
            self.unsubscribe_handled_mqtt = True
        
        @self.mqtt2.on_subscribe()
        def handle_subscribe(client, userdata, mid_, granted_qos):
            self.subscribe_handled_mqtt2 = True
        
        @self.mqtt2.on_unsubscribe()
        def handle_unsubscribe(client, userdata, mid_):
            self.unsubscribe_handled_mqtt2 = True
        
        @self.mqtt3.on_subscribe()
        def handle_subscribe(client, userdata, mid_, granted_qos):
            self.subscribe_handled_mqtt3 = True
        
        @self.mqtt3.on_unsubscribe()
        def handle_unsubscribe(client, userdata, mid_):
            self.unsubscribe_handled_mqtt3 = True

        ret, _ = self.mqtt.subscribe('mqtt/test')
        self.assertEqual(ret, MQTT_ERR_SUCCESS)
        wait()
        self.assertTrue(self.subscribe_handled_mqtt)
        ret, _ = self.mqtt.unsubscribe('mqtt/test')
        self.assertEqual(ret, MQTT_ERR_SUCCESS)
        wait()
        self.assertTrue(self.unsubscribe_handled_mqtt)
        
        ret, _ = self.mqtt2.subscribe('mqtt2/test')
        self.assertEqual(ret, MQTT_ERR_SUCCESS)
        wait()
        self.assertTrue(self.subscribe_handled_mqtt2)
        ret, _ = self.mqtt2.unsubscribe('mqtt2/test')
        self.assertEqual(ret, MQTT_ERR_SUCCESS)
        wait()
        self.assertTrue(self.unsubscribe_handled_mqtt2)
        
        
        ret, _ = self.mqtt3.subscribe('mqtt3/test')
        self.assertEqual(ret, MQTT_ERR_SUCCESS)
        wait()
        self.assertTrue(self.subscribe_handled_mqtt3)
        ret, _ = self.mqtt3.unsubscribe('mqtt3/test')
        self.assertEqual(ret, MQTT_ERR_SUCCESS)
        wait()
        self.assertTrue(self.unsubscribe_handled_mqtt3)

        
        self.mqtt._disconnect()
        self.mqtt2._disconnect()
        self.mqtt3._disconnect()
        
    def test_qos_multiple_servers(self):
        self.mqtt = Mqtt(self.app, config_prefix="MQTT")
        self.mqtt2 = Mqtt(self.app, config_prefix="MQTT2")
        self.mqtt3 = Mqtt(self.app, config_prefix="MQTT3")

        #### mqtt server one ####
        # subscribe to a topic with qos = 1
        self.mqtt.subscribe('mqtt/test', 1)
        self.assertEqual(1, len(self.mqtt.topics))
        self.assertEqual(('mqtt/test', 1), self.mqtt.topics['mqtt/test'])

        # subscribe to same topic, overwrite qos
        self.mqtt.subscribe('mqtt/test', 2)
        self.assertEqual(1, len(self.mqtt.topics))
        self.assertEqual(('mqtt/test', 2), self.mqtt.topics['mqtt/test'])

        # unsubscribe
        self.mqtt.unsubscribe('mqtt/test')
        self.assertEqual(0, len(self.mqtt.topics))
        
        #### mqtt server two ####
        # subscribe to a topic with qos = 1
        self.mqtt2.subscribe('mqtt2/test', 1)
        self.assertEqual(1, len(self.mqtt2.topics))
        self.assertEqual(('mqtt2/test', 1), self.mqtt2.topics['mqtt2/test'])

        # subscribe to same topic, overwrite qos
        self.mqtt2.subscribe('mqtt2/test', 2)
        self.assertEqual(1, len(self.mqtt2.topics))
        self.assertEqual(('mqtt2/test', 2), self.mqtt2.topics['mqtt2/test'])

        # unsubscribe
        self.mqtt2.unsubscribe('mqtt2/test')
        self.assertEqual(0, len(self.mqtt2.topics))
        
        #### mqtt server three ####
        # subscribe to a topic with qos = 1
        self.mqtt3.subscribe('mqtt3/test', 1)
        self.assertEqual(1, len(self.mqtt3.topics))
        self.assertEqual(('mqtt3/test', 1), self.mqtt3.topics['mqtt3/test'])

        # subscribe to same topic, overwrite qos
        self.mqtt3.subscribe('mqtt3/test', 2)
        self.assertEqual(1, len(self.mqtt3.topics))
        self.assertEqual(('mqtt3/test', 2), self.mqtt3.topics['mqtt3/test'])

        # unsubscribe
        self.mqtt3.unsubscribe('mqtt3/test')
        self.assertEqual(0, len(self.mqtt3.topics))
        
        self.mqtt._disconnect()
        self.mqtt2._disconnect()
        self.mqtt3._disconnect()
    
    def test_topic_count_multiple_servers(self):
        self.mqtt = Mqtt(self.app, config_prefix="MQTT")
        self.mqtt2 = Mqtt(self.app, config_prefix="MQTT2")
        self.mqtt3 = Mqtt(self.app, config_prefix="MQTT3")
        
        self.mqtt.subscribe('mqtt/test1')
        self.mqtt.subscribe('mqtt/test2')
        self.assertEqual(2, len(self.mqtt.topics))
        self.mqtt.unsubscribe_all()
        self.assertEqual(0, len(self.mqtt.topics))
        
        self.mqtt2.subscribe('mqtt2/test1')
        self.mqtt2.subscribe('mqtt2/test2')
        self.assertEqual(2, len(self.mqtt2.topics))
        self.mqtt2.unsubscribe_all()
        self.assertEqual(0, len(self.mqtt2.topics))
        
        self.mqtt3.subscribe('mqtt3/test1')
        self.mqtt3.subscribe('mqtt3/test2')
        self.assertEqual(2, len(self.mqtt3.topics))
        self.mqtt3.unsubscribe_all()
        self.assertEqual(0, len(self.mqtt3.topics))
        
        self.mqtt._disconnect()
        self.mqtt2._disconnect()
        self.mqtt3._disconnect()
    
    def test_publish_multiple_servers(self):
        self.mqtt = Mqtt(self.app, config_prefix="MQTT")
        self.mqtt2 = Mqtt(self.app, config_prefix="MQTT2")
        self.mqtt3 = Mqtt(self.app, config_prefix="MQTT3")
        
        ###### mqtt server one ######
        self.handled_message_mqtt = False
        self.handled_publish_mqtt = False
    
        @self.mqtt.on_message()
        def handle_message(client, userdata, message):
            self.handled_message_mqtt = True

        @self.mqtt.on_publish()
        def handle_publish(client, userdata, mid):
            self.handled_publish_mqtt = True

        self.mqtt.subscribe('mqtt/test')
        wait()
        self.mqtt.publish('mqtt/test', 'hello world')
        wait()

        self.assertTrue(self.handled_message_mqtt)
        self.assertTrue(self.handled_publish_mqtt)
        self.mqtt._disconnect()
        
        ###### mqtt server two ######
        self.handled_message_mqtt = False
        self.handled_publish_mqtt = False
    
        @self.mqtt2.on_message()
        def handle_message(client, userdata, message):
            self.handled_message_mqtt = True

        @self.mqtt2.on_publish()
        def handle_publish(client, userdata, mid):
            self.handled_publish_mqtt = True

        self.mqtt2.subscribe('mqtt2/test')
        wait()
        self.mqtt2.publish('mqtt2/test', 'hello world')
        wait()

        self.assertTrue(self.handled_message_mqtt)
        self.assertTrue(self.handled_publish_mqtt)
        self.mqtt2._disconnect()
        
        ###### mqtt server two ######
        self.handled_message_mqtt = False
        self.handled_publish_mqtt = False
    
        @self.mqtt3.on_message()
        def handle_message(client, userdata, message):
            self.handled_message_mqtt = True

        @self.mqtt3.on_publish()
        def handle_publish(client, userdata, mid):
            self.handled_publish_mqtt = True

        self.mqtt3.subscribe('mqtt3/test')
        wait()
        self.mqtt3.publish('mqtt3/test', 'hello world')
        wait()

        self.assertTrue(self.handled_message_mqtt)
        self.assertTrue(self.handled_publish_mqtt)
        self.mqtt3._disconnect()

    def test_logging_multiple_servers(self):
        self.mqtt = Mqtt(self.app, config_prefix="MQTT")
        self.mqtt2 = Mqtt(self.app, config_prefix="MQTT2")
        self.mqtt3 = Mqtt(self.app, config_prefix="MQTT3")

        @self.mqtt.on_log()
        def handle_logging(client, userdata, level, buf):
            self.assertIsNotNone(client)
            self.assertIsNotNone(level)
            self.assertIsNotNone(buf)
        
        @self.mqtt2.on_log()
        def handle_logging(client, userdata, level, buf):
            self.assertIsNotNone(client)
            self.assertIsNotNone(level)
            self.assertIsNotNone(buf)
        
        @self.mqtt3.on_log()
        def handle_logging(client, userdata, level, buf):
            self.assertIsNotNone(client)
            self.assertIsNotNone(level)
            self.assertIsNotNone(buf)

        self.mqtt.publish('mqtt/test', 'hello mqtt')
        self.mqtt.publish('mqtt2/test', 'hello mqtt2')
        self.mqtt.publish('mqtt3/test', 'hello mqtt3')
    
        self.mqtt._disconnect()
        self.mqtt2._disconnect()
        self.mqtt3._disconnect()
    
    def test_disconnect_multiple_servers(self):
        self.mqtt = Mqtt()
        self.mqtt2 = Mqtt()
        self.mqtt3 = Mqtt()
        self.connected = False
        
        ###### mqtt server one ######
        @self.mqtt.on_connect()
        def handle_connect(*args, **kwargs):
            self.connected = True

        @self.mqtt.on_disconnect()
        def handle_disconnect(*args, **kwargs):
            self.connected = False
        
        self.assertFalse(self.connected)
        self.mqtt.init_app(self.app)
        wait()
        self.assertTrue(self.connected)
        self.mqtt._disconnect()
        wait()
        self.assertFalse(self.connected)
        
        ###### mqtt server two ######
        @self.mqtt2.on_connect()
        def handle_connect(*args, **kwargs):
            self.connected = True

        @self.mqtt2.on_disconnect()
        def handle_disconnect(*args, **kwargs):
            self.connected = False
        
        self.assertFalse(self.connected)
        self.mqtt2.init_app(self.app, config_prefix="MQTT2")
        wait()
        self.assertTrue(self.connected)
        self.mqtt2._disconnect()
        wait()
        self.assertFalse(self.connected)
        
        ###### mqtt server one ######
        @self.mqtt3.on_connect()
        def handle_connect(*args, **kwargs):
            self.connected = True

        @self.mqtt3.on_disconnect()
        def handle_disconnect(*args, **kwargs):
            self.connected = False
        
        self.assertFalse(self.connected)
        self.mqtt3.init_app(self.app, config_prefix="MQTT3")
        wait()
        self.assertTrue(self.connected)
        self.mqtt3._disconnect()
        wait()
        self.assertFalse(self.connected)
    
if __name__ == "__main__":
    unittest.main()
    


import sys
import unittest

try:
    from unittest.mock import MagicMock
except ImportError:
    from mock import MagicMock

from flask import Flask


# apply mock
sys.modules['paho.mqtt.client'] = MagicMock()
try:
    sys.modules.pop('flask_mqtt')
except KeyError:
    pass


import flask_mqtt  # noqa: E402
Mqtt = flask_mqtt.Mqtt


class FlaskMQTTTestCase(unittest.TestCase):

    def setUp(self):
        sys.modules['paho.mqtt.client'] = MagicMock()
        self.app = Flask(__name__)

    def test_early_initialization_app_is_not_none(self):
        mqtt = Mqtt(self.app)
        self.assertIsNotNone(mqtt.app)

    def test_late_initialization_app_is_not_none(self):
        mqtt = Mqtt()
        mqtt.init_app(self.app)
        self.assertIsNotNone(mqtt.app)

    def test_mqtt_config_values(self):
        self.app.config['MQTT_USERNAME'] = 'username'
        self.app.config['MQTT_PASSWORD'] = 'password'
        self.app.config['MQTT_BROKER_URL'] = 'broker_url'
        self.app.config['MQTT_BROKER_PORT'] = 'broker_port'
        self.app.config['MQTT_TLS_ENABLED'] = 'tls_enabled'
        self.app.config['MQTT_CLEAN_SESSION'] = False
        self.app.config['MQTT_KEEPALIVE'] = 'keepalive'
        self.app.config['MQTT_LAST_WILL_TOPIC'] = 'home/lastwill'
        self.app.config['MQTT_LAST_WILL_MESSAGE'] = 'last will'
        self.app.config['MQTT_LAST_WILL_QOS'] = 2
        self.app.config['MQTT_LAST_WILL_RETAIN'] = True
        self.app.config['MQTT_TLS_CA_CERTS'] = 'tls_ca_certs'
        self.app.config['MQTT_TLS_CERTFILE'] = 'tls_certfile'
        self.app.config['MQTT_TLS_KEYFILE'] = 'tls_keyfile'
        self.app.config['MQTT_TLS_CERT_REQS'] = 'tls_cert_reqs'
        self.app.config['MQTT_TLS_VERSION'] = 'tls_version'
        self.app.config['MQTT_TLS_CIPHERS'] = 'tls_ciphers'
        self.app.config['MQTT_TLS_INSECURE'] = 'tls_insecure'

        mqtt = Mqtt(self.app)

        self.assertEqual('username', mqtt.username)
        self.assertEqual('password', mqtt.password)
        self.assertEqual('broker_url', mqtt.broker_url)
        self.assertEqual('broker_port', mqtt.broker_port)
        self.assertEqual('tls_enabled', mqtt.tls_enabled)
        self.assertEqual(False, mqtt.clean_session)
        self.assertEqual('keepalive', mqtt.keepalive)
        self.assertEqual('home/lastwill', mqtt.last_will_topic)
        self.assertEqual('last will', mqtt.last_will_message)
        self.assertEqual(2, mqtt.last_will_qos)
        self.assertEqual(True, mqtt.last_will_retain)
        self.assertEqual('tls_ca_certs', mqtt.tls_ca_certs)
        self.assertEqual('tls_certfile', mqtt.tls_certfile)
        self.assertEqual('tls_keyfile', mqtt.tls_keyfile)
        self.assertEqual('tls_cert_reqs', mqtt.tls_cert_reqs)
        self.assertEqual('tls_version', mqtt.tls_version)
        self.assertEqual('tls_ciphers', mqtt.tls_ciphers)
        self.assertEqual('tls_insecure', mqtt.tls_insecure)

        # values passed to paho mqtt
        mqtt.client.username_pw_set.assert_called_once_with('username',
                                                            'password')

        mqtt.client.tls_set.called_once_with(
            ca_certs='tls_ca_certs',
            certfile='tls_certfile',
            keyfile='tls_keyfile',
            cert_reqs='tls_cert_reqs',
            tls_version='tls_version',
            ciphers='tls_ciphers',
        )

    def test_connect_disconnect(self):
        mqtt = Mqtt(self.app)
        self.assertEqual(1, mqtt.client.loop_start.call_count)
        self.assertEqual(1, mqtt.client.connect.call_count)
        mqtt._disconnect()
        self.assertEqual(1, mqtt.client.disconnect.call_count)


if __name__ == '__main__':
    unittest.main()



import sys
import unittest
import time
from flask import Flask


# remove mocks and import flask_mqtt
try:
    sys.modules.pop('paho.mqtt.client')
    sys.modules.pop('flask_mqtt')
except KeyError:
    pass
from flask_mqtt import Mqtt, MQTT_ERR_SUCCESS


def wait(seconds=0.5):
    time.sleep(seconds)


class FlaskMQTTTestCase(unittest.TestCase):

    def setUp(self):

        self.app = Flask(__name__)

    def test_simple_connect(self):
        self.mqtt = Mqtt(self.app)
        self.mqtt._disconnect()

    def test_connect_with_username(self):
        self.app.config['MQTT_USERNAME'] = 'user'
        self.app.config['MQTT_PASSWORD'] = 'secret'
        self.mqtt = Mqtt(self.app)
        self.mqtt._disconnect()

    def test_subscribe(self):
        self.mqtt = Mqtt(self.app)
        self.subscribe_handled = False
        self.unsubscribe_handled = False

        @self.mqtt.on_subscribe()
        def handle_subscribe(client, userdata, mid_, granted_qos):
            self.subscribe_handled = True

        @self.mqtt.on_unsubscribe()
        def handle_unsubscribe(client, userdata, mid_):
            self.unsubscribe_handled = True

        ret, mid = self.mqtt.subscribe('home/test')
        self.assertEqual(ret, MQTT_ERR_SUCCESS)
        wait()

        ret, mid = self.mqtt.unsubscribe('home/test')
        self.assertEqual(ret, MQTT_ERR_SUCCESS)
        wait()

        self.assertTrue(self.subscribe_handled)
        self.assertTrue(self.unsubscribe_handled)

    def test_qos(self):
        self.mqtt = Mqtt(self.app)

        # subscribe to a topic with qos = 1
        self.mqtt.subscribe('test', 1)
        self.assertEqual(1, len(self.mqtt.topics))
        self.assertEqual(('test', 1), self.mqtt.topics['test'])

        # subscribe to same topic, overwrite qos
        self.mqtt.subscribe('test', 2)
        self.assertEqual(1, len(self.mqtt.topics))
        self.assertEqual(('test', 2), self.mqtt.topics['test'])

        # unsubscribe
        self.mqtt.unsubscribe('test')
        self.assertEqual(0, len(self.mqtt.topics))

    def test_topic_count(self):
        self.mqtt = Mqtt(self.app)

        ret, mid = self.mqtt.subscribe('test')
        self.assertEqual(1, len(self.mqtt.topics))

        ret, mid = self.mqtt.subscribe('test')
        self.assertEqual(1, len(self.mqtt.topics))

        self.mqtt.unsubscribe('test')
        self.assertEqual(0, len(self.mqtt.topics))

        self.mqtt.unsubscribe('test')
        self.assertEqual(0, len(self.mqtt.topics))

        ret, mid = self.mqtt.subscribe('test1')
        ret, mid = self.mqtt.subscribe('test2')
        self.assertEqual(2, len(self.mqtt.topics))
        self.mqtt.unsubscribe_all()
        self.assertEqual(0, len(self.mqtt.topics))
        self.mqtt._disconnect()

    def test_publish(self):

        self.mqtt = Mqtt(self.app)
        self.handled_message = False
        self.handled_topic = False
        self.handled_publish = False

        @self.mqtt.on_message()
        def handle_message(client, userdata, message):
            self.handled_message = True

        @self.mqtt.on_publish()
        def handle_publish(client, userdata, mid):
            self.handled_publish = True

        self.mqtt.subscribe('home/test')
        wait()
        self.mqtt.publish('home/test', 'hello world')
        wait()

        self.assertTrue(self.handled_message)
        # self.assertTrue(self.handled_topic)
        self.assertTrue(self.handled_publish)

    def test_on_topic(self):

        self.mqtt = Mqtt(self.app)
        self.handled_message = False
        self.handled_topic = False

        @self.mqtt.on_message()
        def handle_message(client, userdata, message):
            self.handled_message = True

        @self.mqtt.on_topic('home/test')
        def handle_on_topic(*args, **kwargs):
            self.handled_topic = True

        @self.mqtt.on_connect()
        def handle_connect(*args, **kwargs):
            self.mqtt.subscribe('home/test')
            wait()
            self.mqtt.publish('home/test', 'hello world', qos=2)
            wait()
            self.assertFalse(self.handled_message)
            self.assertTrue(self.handled_topic)

    def test_logging(self):
        self.mqtt = Mqtt(self.app)

        @self.mqtt.on_log()
        def handle_logging(client, userdata, level, buf):
            self.assertIsNotNone(client)
            self.assertIsNotNone(level)
            self.assertIsNotNone(buf)

        self.mqtt.publish('test', 'hello world')

    def test_disconnect(self):
        self.mqtt = Mqtt()
        self.connected = False

        @self.mqtt.on_connect()
        def handle_connect(*args, **kwargs):
            self.connected = True

        @self.mqtt.on_disconnect()
        def handle_disconnect(*args, **kwargs):
            self.connected = False

        self.assertFalse(self.connected)
        self.mqtt.init_app(self.app)
        wait()
        self.assertTrue(self.connected)
        self.mqtt._disconnect()
        wait()
        self.assertFalse(self.connected)


if __name__ == '__main__':
    unittest.main()



"""Flask-MQTT Setup."""
import io
import re
import os
import sys
from setuptools import setup


def read(*names, **kwargs):
    """Open a file and read its content."""
    with io.open(
        os.path.join(os.path.dirname(__file__), *names),
        encoding=kwargs.get("encoding", "utf8"),
    ) as fp:
        return fp.read()


def find_version(*file_paths):
    """Find current package version number."""
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]", version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


long_description = read("README.md")


if sys.argv[-1] == "test":
    os.system("coverage run -m unittest discover -s tests")
    os.system("coverage html --include flask_mqtt/*")
    os.system("coverage report -m --include flask_mqtt/*")
else:
    setup(
        name="Flask-MQTT",
        version=find_version("flask_mqtt", "__init__.py"),
        url="https://github.com/MrLeeh/Flask-MQTT",
        license="MIT",
        author="Stefan Lehmann",
        author_email="stefan.st.lehmann@gmail.com",
        description="Flask extension for the MQTT protocol",
        long_description=long_description,
        long_description_content_type="text/markdown",
        packages=["flask_mqtt"],
        platforms="any",
        python_requires=">=3.6",
        install_requires=["Flask", "paho-mqtt<2.0"],
        classifiers=[
            "Development Status :: 5 - Production/Stable",
            "Environment :: Web Environment",
            "Intended Audience :: Developers",
            "License :: OSI Approved :: MIT License",
            "Programming Language :: Python",
            "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
            "Topic :: Software Development :: Libraries :: Python Modules",
        ],
    )
